@@ -1,7 +1,7 @@
 /*
  *  view.h
  *
- *  Copyright (C) 1997, 1998, 2006, 2020 Staf Wagemakers Belgie/Belgium
+ *  Copyright (C) 1997, 1998, 2006, 2020, 2024 Staf Wagemakers Belgie/Belgium
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -24,26 +24,38 @@
 #include "common.h"
 #include "xstring.h"
 #include "win.h"
+#include "color.h"
 #include "getline.h"
 #define TAB 9
-typedef struct 
-{
-ssize_t y,y_max,size;
-ssize_t x,x_max;
-char    mode;
-char    **file;
-char    *filename;
-char    load,cmd;
-char    *txt_f_open2,*txt_f_open1,*txt_f_load;
-char    *txt_f_fseek;
-char    *txt_f_freopen;
-char    ***view_exec;
-MENU    *m_ok;
-WINDOW  *win;
-chtype  *color;
-int     cols,lines;
-int     sx,sy;
+
+typedef struct {
+  ssize_t y;
+  ssize_t y_max;
+  ssize_t size;
+  ssize_t x;
+  ssize_t x_max;
+  ssize_t width;
+  char    mode;
+  char    **file;
+  char    *filename;
+  char    load;
+  char    cmd;
+  char    *txt_f_open2;
+  char    *txt_f_open1;
+  char    *txt_f_load;
+  char    *txt_f_fseek;
+  char    *txt_f_freopen;
+  char    ***view_exec;
+  MENU    *m_ok;
+  WINDOW  *win;
+  chtype  *ansi_colors;
+  int     cols;
+  int     lines;
+  int     sx;
+  int     sy;
+  int     raw;
 } VIEW_PAR;
+
 VIEW_PAR *view_par (VIEW_PAR *par);
 void view_free();
 void view_free_file();
@@ -71,4 +83,7 @@ void view_add_view_exec (int n,char *name, char *val);
 void view_rm_view_exec(int n);
 char **view_view_exec_2_string_array();
 char **view_view_exec_2_trimmed_string_array(int width);
+void view_recal_xmax();
+int view_set_raw(int raw);
+int view_get_raw(int raw);
 #endif
