@@ -1,7 +1,7 @@
 /*
  * xstring.h
  *
- *  Copyright (C) 2001, 2006, 2020  Staf Wagemakers Belgie/Belgium
+ *  Copyright (C) 2001, 2006, 2020. 2025  Staf Wagemakers Belgie/Belgium
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -56,11 +56,13 @@ int update_string_pair_item(char ***str_pair,char *item, char *value, int free_m
 int delete_string_pair_item(char ***str_pair,char *item,int free_mode);
 char * clone_string(char *str);
 void free_string_pair (char *** str_pair );
-unsigned utf8_strsize(char *c);
+unsigned utf8_charsize(char *c);
+unsigned ansi_charsize(char *c);
 void replace_char(char *str,char src,char dest);
 char * null2str(char *str);
 char * utf8_firstchar(char *c);
 unsigned utf8_strlen(char *str);
+unsigned ansi_utf8_strlen(char *str);
 char * right_align_2_strings(char * str1, char * str2, int width);
 char * str_nchars(int n, char c);
 char ** combine_string_array_pointers( char **src1, char **src2);
